Sendable

Struct Sendable 

pub struct Sendable { /* private fields */ }
Marker type that indicates you expect everything in the DynamicArena to be Send

Although this prevents you from allocating non-Send types in the arena, it allows you to Send the dynamic itself arena across threads. We can’t safely implement Send for DynamicArena without this bound, since you could otherwise place a Rc in the arena, send it across threads, and then proceed to drop the arena and mutate the reference count.